/*-
 * Copyright (c) 2001 Eugene Ossintsev
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: font.h,v 1.4 2001/12/21 23:30:44 gene Exp $
 */

#ifndef _FONT_H_
#define _FONT_H_

/* The structure describing font */
struct CFE_FONT {
    char *name;
    unsigned char *file;
    unsigned char *data;
    unsigned short *unicode_data;
    int size;
    int type;
    short height;
    int offset;
    short num_of_chars;
};

/* Font data types */
enum CFE_FONT_TYPE {
    F_RAW,
    F_PSF,
    F_ERR       /* corrupted font data */
};

/* The structure for working with glyph */
struct CFE_GLYPH {
    unsigned char *data;
    short num;
    short x;
    short y;
};

/* Create font file */
int create_font_file(struct CFE_FONT *font);

/* Load font file.
 * Returns -1 if file doesn't exist.
 */
int load_font_file(struct CFE_FONT *font,
                   int is_offset, int is_height);

/* Save font file */
int save_font_file(struct CFE_FONT *font);

/* Autodetects whether it is PSF or RAW font file. Returns FONT_TYPE. */
int psf_or_raw(struct CFE_FONT *font);

/* On success the string with Unicode numbers matched
 * by glyph_num is copied into str.
 * Returns zero if font doesn't contain Unicode table.
 */
int get_unicode_data(struct CFE_FONT *font, short glyph_num, char *str);

/* Set the data in the row and in the current row.
 * Operates only on glyph[0] !
 */
void set_glyph_row(int row, unsigned char data);
void set_glyph_cur_row(unsigned char data);

/* Get the data from the row and from the current row.
 * Operates only on glyph[0] !
 */
unsigned char get_glyph_row(int row);
unsigned char get_glyph_cur_row();


#endif  /* _FONT_H_ */


/* EOF */
